pub enum HorizontalAlignment {
Left,
Center,
Right,
}Expand description
The horizontal alignment of a column’s content.
Specified by a horizontal alignment operator at the start of a
column specifier: the less-than sign (<) for
Left, the greater-than sign (>) for
Right, and the caret (^) for Center.
The default is Left.
Variants
Left
Content is aligned to the left side of the column (the < operator).
This is the default horizontal alignment.
Center
Content is centered horizontally in the column (the ^ operator).
Right
Content is aligned to the right side of the column (the > operator).