ListType

Enum ListType 

pub enum ListType {
    Unordered,
    Ordered,
    Description,
}
Represents the type of a list.

Variants



Unordered

An unordered list is a list with items prefixed with symbol, such as a disc (aka bullet).



Ordered

An ordered list is a list with items prefixed with a number or other sequential mark.



Description

A description list is an association list that consists of one or more terms (or sets of terms) that each have a description.