pub enum VerticalAlignment {
Top,
Middle,
Bottom,
}Expand description
The vertical alignment of a column’s content.
Specified by a vertical alignment operator on a
column specifier, always introduced by a dot (.): .< for
Top, .> for Bottom, and .^ for
Middle. The default is Top.
Variants
Top
Content is aligned to the top of the column’s cells (the .< operator).
This is the default vertical alignment.
Middle
Content is centered vertically in the column’s cells (the .^
operator).
Bottom
Content is aligned to the bottom of the column’s cells (the .>
operator).