pub struct AdmonitionBlock<'src> { /* private fields */ }Expand description
An admonition draws attention to a statement by taking it out of the content’s flow and labeling it with a priority (its type).
An admonition can be written in two ways:
- As a paragraph whose first line begins with one of the five admonition
labels followed by a colon (e.g.,
NOTE: This is a note.). This produces an admonition with theSimplecontent model. - As a block by setting one of the labels as the block style in an
attribute list (e.g.,
[NOTE]). This is referred to as masquerading. When the style is set on a delimited block that can contain other blocks (such as an example block), the admonition uses theCompoundcontent model; otherwise it uses theSimplecontent model.
Implementations
Sourceimpl<'src> AdmonitionBlock<'src>
impl<'src> AdmonitionBlock<'src>
Sourcepub fn variant(&self) -> AdmonitionVariant
pub fn variant(&self) -> AdmonitionVariant
Returns the admonition type (e.g., AdmonitionVariant::Note).
Sourcepub fn name(&self) -> &'static str
pub fn name(&self) -> &'static str
Returns the lowercase name for this admonition (e.g., note).
Sourcepub fn label(&self) -> &str
pub fn label(&self) -> &str
Returns the caption (label) text shown for this admonition (e.g.,
Note).
This is the value of the <type>-caption document attribute if set, or
the default caption for the admonition type otherwise.
Sourcepub fn icons_font(&self) -> bool
pub fn icons_font(&self) -> bool
Returns true if font-based icons are enabled (i.e., the icons
document attribute is set to font).