ListItem

Struct ListItem 

pub struct ListItem<'src> { /* private fields */ }
A list item is a special kind of block that contains one or more blocks attached to it. In the simplest case, this will be a single SimpleBlock with the principal text for the list item. In other cases, it may be any number of blocks of any type which, together, form an entry in a list which is the immediate parent of this block.

Implementations

Source

impl<'src> ListItem<'src>

pub fn child_blocks(&'src self) -> ChildBlocks<'src>

Returns a document-order iterator over this list item’s direct child blocks.

For the full subtree, or to search from a Block or Document, use FindBlocks.

pub fn list_item_marker(&self) -> ListItemMarker<'src>

Returns the list item marker that was used for this item.

pub fn checkbox(&self) -> Option<bool>

Returns the checklist (i.e. task list) state of this item.

An unordered list item whose principal text begins with a checkbox marker ([ ] , [x] , or [*] ) is a checklist item. The returned value is Some(true) for a checked item ([x]/[*]), Some(false) for an unchecked item ([ ]), or None if the item is not a checklist item.

pub fn has_empty_principal_text(&self) -> bool

Reports whether this item has principal text that is present in the source but renders empty (for example, principal text written as the {empty} attribute reference).

Such an empty principal text node is not emitted as a child block (see child_blocks); this flag preserves the fact that it was there. It distinguishes an item whose principal text is empty – so a renderer emits an empty principal paragraph ahead of any continuation-attached blocks (as Asciidoctor does) – from an item that simply has no principal text. When it is true, the item’s first child block is an attached block rather than the principal text.