pub struct MediaBlock<'src> { /* private fields */ }Expand description
A media block is used to represent an image, video, or audio block macro.
Implementations
Sourceimpl<'src> MediaBlock<'src>
impl<'src> MediaBlock<'src>
Sourcepub fn child_blocks(&'src self) -> ChildBlocks<'src> ⓘ
pub fn child_blocks(&'src self) -> ChildBlocks<'src> ⓘ
Returns a document-order iterator over this block’s direct child blocks.
A media block (image, audio, or video) never has child blocks, so this
iterator is always empty. See FindBlocks
to search from a Block or
Document.
Sourcepub fn target(&'src self) -> Option<&'src Span<'src>>
pub fn target(&'src self) -> Option<&'src Span<'src>>
Return a Span describing the macro target.
This is the target exactly as written in the source, before any
attribute references within it are resolved. See
resolved_target() for the resolved form.
Sourcepub fn resolved_target(&self) -> &str
pub fn resolved_target(&self) -> &str
Return the macro target after any attribute references within it have
been resolved (honoring the attribute-missing document attribute).
For the common case of a target with no attribute references, this is
identical to the text of target().
Sourcepub fn macro_attrlist(&'src self) -> &'src Attrlist<'src>
pub fn macro_attrlist(&'src self) -> &'src Attrlist<'src>
Return the macro’s attribute list.
IMPORTANT: This is the list of attributes within the macro block definition itself.
See also attrlist() for attributes that can be defined before the
macro invocation.