Module document

Module document 

Describes the top-level document structure.

Structs

Attribute
Document attributes are effectively document-scoped variables for the AsciiDoc language. The AsciiDoc language defines a set of built-in attributes, and also allows the author (or extensions) to define additional document attributes, which may replace built-in attributes when permitted.
Author
Represents a single author as (typically) described on the author line.
AuthorLine
The author line is directly after the document title line in the document header. When the content on this line is structured correctly, the processor assigns the content to the built-in author and email attributes.
Catalog
Document catalog for tracking referenceable elements.
Document
A document represents the top-level block element in AsciiDoc. It consists of an optional document header and either a) one or more sections preceded by an optional preamble or b) a sequence of top-level blocks only.
Footnote
A footnote registered while substituting the inline footnote:[…] macro.
Header
An AsciiDoc document may begin with a document header. The document header encapsulates the document title, author and revision information, document-wide attributes, and other document metadata.
RefEntry
Entry in the document catalog representing a referenceable element.
RevisionLine
The revision line is the line directly after the author line in the document header. When the content on this line is structured correctly, the processor assigns the content to the built-in revnumber, revdate, and revremark attributes.

Enums

DocinfoLocation
Where a docinfo file’s content is injected into the converted output.
InterpretedValue
The interpreted value of an Attribute.
RefType
Type of referenceable element in the document.
TocMode
Where (and whether) a document’s table of contents (TOC) is generated, resolved from the toc attribute.