pub enum DocinfoLocation {
Head,
Header,
Footer,
}Expand description
Where a docinfo file’s content is injected into the converted output.
Each location corresponds to a distinct set of docinfo files (differentiated by name) and a distinct insertion point in the output document.
Variants
Head
Head docinfo: injected into the top of the document (appended to the
HTML <head> element, or the DocBook root <info> element).
Header
Header docinfo: injected at the start of the document body (immediately
before the HTML header <div>).
Footer docinfo: injected at the end of the document body (immediately
after the HTML footer <div>).