pub struct ImageReference {
pub target: String,
pub imagesdir: Option<String>,
}Expand description
Fields
target: StringThe image target as written in the macro, after attribute references in
the target have been substituted (e.g. fixtures/dot.gif).
imagesdir: Option<String>The value of the imagesdir document attribute at the point of
reference, or None when it was unset.