pub enum QuoteScope {
Constrained,
Unconstrained,
}Expand description
Specifies whether the block is aligned to word boundaries or not.
Variants
Constrained
The quoted section was aligned to word boundaries.
Unconstrained
The quoted section may not have been aligned to word boundaries.