pub struct CalloutRenderParams<'a> {
pub number: &'a str,
pub guard: CalloutGuard<'a>,
pub parser: &'a Parser,
}Expand description
Provides parameters for rendering a callout number.
Fields
number: &'a strThe callout number to display. For automatically-numbered callouts
(<.>), this is the resolved sequential number.
guard: CalloutGuard<'a>The guard surrounding the callout in the source. This controls whether (and how) the line-comment or XML-comment characters that hide the callout in the raw source are preserved in the output when icons are not enabled.
parser: &'a ParserParser. The renderer reads the icons, iconsdir, and icontype
document attributes to decide how to render the callout.