MenuRenderParams

Struct MenuRenderParams 

pub struct MenuRenderParams<'a> {
    pub menu: &'a str,
    pub submenus: &'a [String],
    pub menuitem: Option<&'a str>,
    pub parser: &'a Parser,
}
Provides parameters for rendering a menu UI macro.

Fields

menu: &'a str

The top-level menu name.

submenus: &'a [String]

Zero or more intermediate submenu names, in order from outermost to innermost.

menuitem: Option<&'a str>

The final menu item, if any. None renders a bare menu reference (a menu:File[] with no items).

parser: &'a Parser

Parser, used to read the icons document attribute when choosing how to render the caret between menu levels.