pub struct ListItem<'src> { /* private fields */ }Expand description
A list item is a special kind of block that contains one or more blocks
attached to it. In the simplest case, this will be a single SimpleBlock
with the principal text for the list item. In other cases, it may be any
number of blocks of any type which, together, form an entry in a list which
is the immediate parent of this block.
Implementations
Sourceimpl<'src> ListItem<'src>
impl<'src> ListItem<'src>
Sourcepub fn child_blocks(&'src self) -> ChildBlocks<'src> ⓘ
pub fn child_blocks(&'src self) -> ChildBlocks<'src> ⓘ
Returns a document-order iterator over this list item’s direct child blocks.
For the full subtree, or to search from a Block or Document, use
FindBlocks.
Sourcepub fn list_item_marker(&self) -> ListItemMarker<'src>
pub fn list_item_marker(&self) -> ListItemMarker<'src>
Returns the list item marker that was used for this item.
Sourcepub fn checkbox(&self) -> Option<bool>
pub fn checkbox(&self) -> Option<bool>
Returns the checklist (i.e. task list) state of this item.
An unordered list item whose principal text begins with a checkbox
marker ([ ] , [x] , or [*] ) is a checklist item. The returned
value is Some(true) for a checked item ([x]/[*]), Some(false)
for an unchecked item ([ ]), or None if the item is not a checklist
item.