pub struct ListItem<'src> { /* private fields */ }Expand description
A list item is a special kind of block that contains one or more blocks
attached to it. In the simplest case, this will be a single SimpleBlock
with the principal text for the list item. In other cases, it may be any
number of blocks of any type which, together, form an entry in a list which
is the immediate parent of this block.
Implementations
Sourceimpl<'src> ListItem<'src>
impl<'src> ListItem<'src>
Sourcepub fn list_item_marker(&self) -> ListItemMarker<'src>
pub fn list_item_marker(&self) -> ListItemMarker<'src>
Returns the list item marker that was used for this item.