ImageReference

Struct ImageReference 

pub struct ImageReference {
    pub target: String,
    pub imagesdir: Option<String>,
}
A reference to an image asset recorded in the document Catalog when catalog_assets is enabled.

Mirrors Asciidoctor’s Document::ImageReference: it pairs the image target with the value of the imagesdir attribute in effect where the image was referenced.

Fields

target: String

The image target as written in the macro, after attribute references in the target have been substituted (e.g. fixtures/dot.gif).

imagesdir: Option<String>

The value of the imagesdir document attribute at the point of reference, or None when it was unset.