Module parser

Module parser 

The Parser struct and its related structs allow a caller to configure how AsciiDoc parsing occurs and then to initiate the parsing process.

Structs

CalloutRenderParams
Provides parameters for rendering a callout number.
CatalogResolver
The default single-document ReferenceResolver, backed by one Catalog.
FootnoteRenderParams
Provides parameters for rendering the inline marker of a footnote macro.
HtmlSubstitutionRenderer
Implementation of InlineSubstitutionRenderer that renders substitutions for common HTML-based applications.
IconRenderParams
Provides parsed parameters for an icon to be rendered.
ImageRenderParams
Provides parsed parameters for an image to be rendered.
IndexTermRenderParams
Provides parameters for rendering an index term.
LinkRenderParams
Provides parsed parameters for an icon to be rendered.
MenuRenderParams
Provides parameters for rendering a menu UI macro.
Parser
The Parser struct and its related structs allow a caller to configure how AsciiDoc parsing occurs and then to initiate the parsing process.
PathResolver
A PathResolver handles all operations for resolving, cleaning, and joining paths. This struct includes operations for handling both web paths (request URIs) and system paths.
ReferenceWarning
A warning produced while resolving cross-references.
ResolutionContext
Describes a single cross-reference that needs to be resolved.
ResolvedReference
The resolved destination of a cross-reference.
SourceLine
A SourceLine represents the original file and line number where a line of Asciidoc text was found before include file and conditional pre-processing occurred.
SourceMap
Generated by preprocessor: Sparse map of result (Span) line number to a tuple of file name and line number. This allows us to work backwards from the pre-processed and unified Span to the various inputs that were used to construct it. Line numbers here are 1-based.
XrefRenderParams
Provides parameters for rendering a cross-reference.

Enums

AllowableValue
Allowable values for the attribute.
CalloutGuard
Describes the characters that guard (hide) a callout number in verbatim source.
CharacterReplacementType
Specifies which character replacement is being rendered.
LinkRenderType
What type of link is being rendered?
ModificationContext
Allowable context(s) for modification of this attribute value.
QuoteScope
Specifies whether the block is aligned to word boundaries or not.
QuoteType
Specifies which quote type is being rendered.
ReferenceWarningKind
The kind of problem described by a ReferenceWarning.
SafeMode
Describes the safe mode under which a document is parsed and rendered.
SpecialCharacter
Specifies which special character is being replaced in a call to InlineSubstitutionRenderer::render_special_character.

Traits

DocinfoFileHandler
A DocinfoFileHandler is responsible for providing the text content of a docinfo file when one is requested while resolving a document’s docinfo.
IncludeFileHandler
An IncludeFileHandler is responsible for providing the text content for an include:: directive when encountered.
InlineSubstitutionRenderer
An implementation of InlineSubstitutionRenderer is used when converting the basic raw text of a simple block to the format which will ultimately be presented in the final converted output.
ReferenceResolver
Resolves cross-reference targets to their destinations.
SvgFileHandler
An SvgFileHandler is responsible for providing the raw contents of an SVG file when an inline image macro requests that the SVG be embedded directly in the output (image:target.svg[opts=inline]).