The Parser struct and its related structs allow a caller to configure
how AsciiDoc parsing occurs and then to initiate the parsing process.
Structs
- Catalog
Resolver - The default single-document
ReferenceResolver, backed by oneCatalog. - Html
Substitution Renderer - Implementation of
InlineSubstitutionRendererthat renders substitutions for common HTML-based applications. - Icon
Render Params - Provides parsed parameters for an icon to be rendered.
- Image
Render Params - Provides parsed parameters for an image to be rendered.
- Link
Render Params - Provides parsed parameters for an icon to be rendered.
- Parser
- The
Parserstruct and its related structs allow a caller to configure how AsciiDoc parsing occurs and then to initiate the parsing process. - Path
Resolver - A
PathResolverhandles all operations for resolving, cleaning, and joining paths. This struct includes operations for handling both web paths (request URIs) and system paths. - Reference
Warning - A warning produced while resolving cross-references.
- Resolution
Context - Describes a single cross-reference that needs to be resolved.
- Resolved
Reference - The resolved destination of a cross-reference.
- Source
Line - A
SourceLinerepresents the original file and line number where a line of Asciidoc text was found before include file and conditional pre-processing occurred. - Source
Map - Generated by preprocessor: Sparse map of result (
Span) line number to a tuple of file name and line number. This allows us to work backwards from the pre-processed and unifiedSpanto the various inputs that were used to construct it. Line numbers here are 1-based. - Xref
Render Params - Provides parameters for rendering a cross-reference.
Enums
- Allowable
Value - Allowable values for the attribute.
- Character
Replacement Type - Specifies which character replacement is being rendered.
- Link
Render Type - What type of link is being rendered?
- Modification
Context - Allowable context(s) for modification of this attribute value.
- Quote
Scope - Specifies whether the block is aligned to word boundaries or not.
- Quote
Type - Specifies which quote type is being rendered.
- Reference
Warning Kind - The kind of problem described by a
ReferenceWarning. - Special
Character - Specifies which special character is being replaced in a call to
InlineSubstitutionRenderer::render_special_character.
Traits
- Include
File Handler - An
IncludeFileHandleris responsible for providing the text content for aninclude::directive when encountered. - Inline
Substitution Renderer - An implementation of
InlineSubstitutionRendereris used when converting the basic raw text of a simple block to the format which will ultimately be presented in the final converted output. - Reference
Resolver - Resolves cross-reference targets to their destinations.