SourceMap

Struct SourceMap 

pub struct SourceMap(pub Vec<(usize, SourceLine)>);
Generated by preprocessor: Sparse map of result (Span) line number to a tuple of file name and line number. This allows us to work backwards from the pre-processed and unified Span to the various inputs that were used to construct it. Line numbers here are 1-based.

Tuple Fields

0: Vec<(usize, SourceLine)>

Implementations

Source

impl SourceMap

pub fn original_file_and_line(&self, key: usize) -> Option<SourceLine>

Given a 1-based line number in the preprocessed source file, translate that to a file name and line number as original inputs to the parsing process.